diff --git a/types/office-js-preview/index.d.ts b/types/office-js-preview/index.d.ts
index dec070dad5..0cbe21fa4d 100644
--- a/types/office-js-preview/index.d.ts
+++ b/types/office-js-preview/index.d.ts
@@ -1661,7 +1661,7 @@ declare namespace Office {
* Specifies how to coerce data returned or set by the invoked method.
*
* @remarks
* PowerPoint supports only `Office.CoercionType.Text`, `Office.CoercionType.Image`, and `Office.CoercionType.SlideRange`.
*
* Project supports only `Office.CoercionType.Text`.
*
@@ -1726,7 +1726,12 @@ declare namespace Office {
* Data is returned or set as an image stream.
* Note: Only applies to data in Excel, Word, and PowerPoint.
*/
- Image
+ Image,
+ /**
+ * Data is returned or set as XML data containing an SVG image.
+ * Note: Only applies to data in Excel, Word, and PowerPoint.
+ */
+ XmlSvg
}
/**
* Specifies whether the document in the associated application is read-only or read-write.
@@ -3543,6 +3548,10 @@ declare namespace Office {
*
PowerPoint and PowerPoint Online |
* `Office.CoercionType.SlideRange` |
*
+ *
+ * | Excel, PowerPoint, and Word |
+ * `Office.CoercionType.XmlSvg` |
+ *
*
*
* **Support details**
@@ -3710,6 +3719,10 @@ declare namespace Office {
* PowerPoint and PowerPoint Online |
* `Office.CoercionType.SlideRange` |
*
+ *
+ * | Excel, PowerPoint, and Word |
+ * `Office.CoercionType.XmlSvg` |
+ *
*
*
* **Support details**
@@ -1661,7 +1661,7 @@ declare namespace Office {
*
* @remarks
- * PowerPoint supports only `Office.CoercionType.Text`, `Office.CoercionType.Image`, and `Office.CoercionType.SlideRange`.
+ * PowerPoint supports only `Office.CoercionType.Text`, `Office.CoercionType.Image`, `Office.CoercionType.SlideRange`, and `Office.CoercionType.XmlSvg`.
*
* Project supports only `Office.CoercionType.Text`.
diff --git a/types/office-js/index.d.ts b/types/office-js/index.d.ts
index 005e9cf037..b15cd3653a 100644
--- a/types/office-js/index.d.ts
+++ b/types/office-js/index.d.ts
@@ -1661,7 +1661,7 @@ declare namespace Office {
* Specifies how to coerce data returned or set by the invoked method.
*
* @remarks
* PowerPoint supports only `Office.CoercionType.Text`, `Office.CoercionType.Image`, and `Office.CoercionType.SlideRange`.
*
* Project supports only `Office.CoercionType.Text`.
*
@@ -1726,7 +1726,12 @@ declare namespace Office {
* Data is returned or set as an image stream.
* Note: Only applies to data in Excel, Word, and PowerPoint.
*/
- Image
+ Image,
+ /**
+ * Data is returned or set as XML data containing an SVG image.
+ * Note: Only applies to data in Excel, Word, and PowerPoint.
+ */
+ XmlSvg
}
/**
* Specifies whether the document in the associated application is read-only or read-write.
@@ -3543,6 +3548,10 @@ declare namespace Office {
* PowerPoint and PowerPoint Online |
* `Office.CoercionType.SlideRange` |
*
+ *
+ * | Excel, PowerPoint, and Word |
+ * `Office.CoercionType.XmlSvg` |
+ *
*
*
* **Support details**
@@ -3710,6 +3719,10 @@ declare namespace Office {
* PowerPoint and PowerPoint Online |
* `Office.CoercionType.SlideRange` |
*
+ *
+ * | Excel, PowerPoint, and Word |
+ * `Office.CoercionType.XmlSvg` |
+ *
*
*
* **Support details**
@@ -1661,7 +1661,7 @@ declare namespace Office {
*
* @remarks
- * PowerPoint supports only `Office.CoercionType.Text`, `Office.CoercionType.Image`, and `Office.CoercionType.SlideRange`.
+ * PowerPoint supports only `Office.CoercionType.Text`, `Office.CoercionType.Image`, `Office.CoercionType.SlideRange`, and `Office.CoercionType.XmlSvg`.
*
* Project supports only `Office.CoercionType.Text`.